Coverage for /media/ldata/code/tendril/tendril/frontend/blueprints/inventory/views.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/frontend/blueprints/inventory/views.py : 0%

## 22 statements 0 run 22 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 | #!/usr/bin/env python # encoding: utf-8 # Copyright (C) 2015 Chintalagiri Shashank # # This file is part of tendril. # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU Affero General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU Affero General Public License for more details. # # You should have received a copy of the GNU Affero General Public License # along with this program. If not, see <http://www.gnu.org/licenses/>. """ Docstring for views """ from flask import render_template from flask_user import login_required from . import inventory as blueprint from tendril.inventory import electronics as invelectronics from tendril.utils.fsutils import Crumb @blueprint.route('/<location_idx>') @blueprint.route('/') @login_required def status(location_idx=None): # Presently only supports getting the latest result. A way to allow # any result to be retrieved would be nice. if location_idx is None: locs = invelectronics.inventory_locations idents = [] for loc in locs: for line in loc.lines: if line.ident not in idents: idents.append(line.ident) stage = {'idents': idents, 'locs': locs, 'crumbroot': '/inventory', 'inv': invelectronics, 'breadcrumbs': [Crumb(name="Inventory", path="/"), Crumb(name="Status", path="location/")], } return render_template('status.html', stage=stage, pagetitle="All Inventory Locations") else: loc = invelectronics.inventory_locations[int(location_idx)] stage = {'loc': loc, 'crumbroot': '/inventory', 'breadcrumbs': [Crumb(name="Inventory", path="/"), Crumb(name="Status", path="location/"), Crumb(name=loc.name, path="location/" + location_idx)], # noqa } return render_template('location_detail.html', stage=stage, pagetitle="Inventory Location " + loc.name)